@@ -41,11 +41,15 @@
 #define GSM_LOGOUT_DIALOG_GET_PRIVATE(o)                                \
         (G_TYPE_INSTANCE_GET_PRIVATE ((o), GSM_TYPE_LOGOUT_DIALOG, GsmLogoutDialogPrivate))
 
-#define AUTOMATIC_ACTION_TIMEOUT 60
-
 #define GSM_ICON_LOGOUT   "system-log-out"
 #define GSM_ICON_SHUTDOWN "system-shutdown"
 
+#define SESSION_SCHEMA     "org.mate.session"
+#define KEY_LOGOUT_TIMEOUT "logout-timeout"
+
+#define LOCKDOWN_SCHEMA            "org.mate.lockdown"
+#define KEY_USER_SWITCHING_DISABLE "disable-user-switching"
+
 typedef enum {
         GSM_DIALOG_LOGOUT_TYPE_LOGOUT,
         GSM_DIALOG_LOGOUT_TYPE_SHUTDOWN
@@ -241,14 +245,23 @@ gsm_logout_supports_system_hibernate (GsmLogoutDialog *logout_dialog)
 static gboolean
 gsm_logout_supports_switch_user (GsmLogoutDialog *logout_dialog)
 {
-        gboolean ret;
+        GSettings *settings;
+        gboolean   ret = FALSE;
+	gboolean   locked;
 
+        settings = g_settings_new (LOCKDOWN_SCHEMA);
+
+	locked = g_settings_get_boolean (settings, KEY_USER_SWITCHING_DISABLE);
+	g_object_unref (settings);
+
+	if (!locked) {
 #ifdef HAVE_SYSTEMD
-        if (LOGIND_RUNNING())
-            ret = gsm_systemd_can_switch_user (logout_dialog->priv->systemd);
-        else
+            if (LOGIND_RUNNING())
+                ret = gsm_systemd_can_switch_user (logout_dialog->priv->systemd);
+            else
 #endif
-        ret = gsm_consolekit_can_switch_user (logout_dialog->priv->consolekit);
+            ret = gsm_consolekit_can_switch_user (logout_dialog->priv->consolekit);
+        }
 
         return ret;
 }
@@ -397,18 +410,29 @@ gsm_logout_dialog_timeout (gpointer data)
 static void
 gsm_logout_dialog_set_timeout (GsmLogoutDialog *logout_dialog)
 {
-        logout_dialog->priv->timeout = AUTOMATIC_ACTION_TIMEOUT;
+        GSettings *settings;
 
-        /* Sets the secondary text */
-        gsm_logout_dialog_timeout (logout_dialog);
+        settings = g_settings_new (SESSION_SCHEMA);
 
-        if (logout_dialog->priv->timeout_id != 0) {
-                g_source_remove (logout_dialog->priv->timeout_id);
+        logout_dialog->priv->timeout = g_settings_get_int (settings, KEY_LOGOUT_TIMEOUT);
+
+        if (logout_dialog->priv->timeout > 0) {
+                /* Sets the secondary text */
+                gsm_logout_dialog_timeout (logout_dialog);
+
+                if (logout_dialog->priv->timeout_id != 0) {
+                        g_source_remove (logout_dialog->priv->timeout_id);
+                }
+
+                logout_dialog->priv->timeout_id = g_timeout_add (1000,
+                                                                 gsm_logout_dialog_timeout,
+                                                                 logout_dialog);
+        }
+        else {
+                gtk_widget_hide (logout_dialog->priv->progressbar);
         }
 
-        logout_dialog->priv->timeout_id = g_timeout_add (1000,
-                                                         gsm_logout_dialog_timeout,
-                                                         logout_dialog);
+        g_object_unref (settings);
 }
 
 static GtkWidget *
@@ -505,6 +529,9 @@ gsm_get_dialog (GsmDialogLogoutType type,
         hbox = gtk_hbox_new (FALSE, 0);
 #endif
         logout_dialog->priv->progressbar = gtk_progress_bar_new ();
+#if GTK_CHECK_VERSION (3, 0, 0)
+        gtk_progress_bar_set_show_text (GTK_PROGRESS_BAR (logout_dialog->priv->progressbar), TRUE);
+#endif
         gtk_progress_bar_set_fraction (GTK_PROGRESS_BAR (logout_dialog->priv->progressbar), 1.0);
         gtk_box_pack_start (GTK_BOX (hbox),
                             logout_dialog->priv->progressbar,
