@@ -74,10 +74,10 @@
 #define MOBILITY_KEY          "exec"
 #define MOBILITY_STARTUP_KEY  "startup"
 
-#define GSM_DBUS_NAME "org.mate.SessionManager"
+#define MATE_INTERFACE_SCHEMA "org.mate.interface"
+#define GTK_OVERLAY_SCROLL    "gtk-overlay-scrolling"
 
-#define IS_STRING_EMPTY(x) \
-	((x) == NULL || (x)[0] == '\0')
+#define GSM_DBUS_NAME "org.gnome.SessionManager"
 
 #define KEY_AUTOSAVE "auto-save-session"
 
@@ -537,6 +537,23 @@ void debug_changed (GSettings *settings, gchar *key, gpointer user_data)
 	mdm_log_set_debug (debug);
 }
 
+static void set_overlay_scroll (void)
+{
+	GSettings *settings;
+	gboolean   enabled;
+
+	settings = g_settings_new (MATE_INTERFACE_SCHEMA);
+	enabled = g_settings_get_boolean (settings, GTK_OVERLAY_SCROLL);
+
+	if (enabled) {
+		gsm_util_setenv ("GTK_OVERLAY_SCROLLING", "1");
+	} else {
+		gsm_util_setenv ("GTK_OVERLAY_SCROLLING", "0");
+	}
+
+	g_object_unref (settings);
+}
+
 int main(int argc, char** argv)
 {
 	struct sigaction sa;
@@ -641,6 +658,9 @@ int main(int argc, char** argv)
 	/* Starts gnome compat mode */
 	msm_gnome_start();
 
+	/* Set to use Gtk3 overlay scroll */
+	set_overlay_scroll ();
+
 	manager = gsm_manager_new(client_store, failsafe);
 
 	signal_handler = mdm_signal_handler_new();
